@@ -12,6 +12,7 @@ class TenantFileSystemStorage(FileSystemStorage):
     """
     Standard filesystem tenant storage
     """
+
     def get_relative_tenant_location(self):
         with suppress(AttributeError):
             tenant = get_current_tenant()
@@ -22,15 +23,14 @@ class TenantFileSystemStorage(FileSystemStorage):
     def get_relative_tenant_url(self):
         with suppress(AttributeError):
             tenant = get_current_tenant()
-            return urljoin(settings.MEDIA_URL, str(tenant.id) + '/')
+            return urljoin(settings.MEDIA_URL, str(tenant.id) + "/")
 
         return settings.MEDIA_URL
 
     @property
     def base_location(self):  # Not cached like in parent class
         return self._value_or_setting(
-            self._location,
-            self.get_relative_tenant_location()
+            self._location, self.get_relative_tenant_location()
         )
 
     @property
@@ -39,10 +39,9 @@ class TenantFileSystemStorage(FileSystemStorage):
 
     @property
     def base_url(self):  # Not cached like in parent class
-        if self._base_url is not None and not self._base_url.endswith('/'):
-            self._base_url += '/'
+        if self._base_url is not None and not self._base_url.endswith("/"):
+            self._base_url += "/"
 
         return self._value_or_setting(
-            self._base_url,
-            self.get_relative_tenant_url()
+            self._base_url, self.get_relative_tenant_url()
         )
